.dash-item-container .overview-tile .overview-icon,
.dash-item-container .show-apps .overview-icon {
  background-color: rgba(255, 255, 255, 0); }

.dash-item-container .overview-tile:hover .overview-icon,
.dash-item-container .overview-tile.focused .overview-icon,
.dash-item-container .show-apps:hover .overview-icon {
  background-color: rgba(238, 238, 238, 0.2); }

.dash-item-container .overview-tile .app-grid-running-dot {
  margin-bottom: 8px;
  offset-y: 2px; }

#dashtodockContainer.bottom #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.bottom #dash .dash-background {
    margin: 0;
    margin-bottom: 4px;
    padding: 0;
    border-radius: 24px;
    spacing: 6px; }
  #dashtodockContainer.bottom #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    margin: 0 4px;
    width: 1px;
    height: 0;
    margin-bottom: 4px; }
  #dashtodockContainer.bottom #dash #dashtodockDashContainer {
    padding: 10px;
    padding-bottom: 0;
    padding-top: 0; }
  #dashtodockContainer.bottom #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 0 2px; }
    #dashtodockContainer.bottom #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.bottom #dash .dash-item-container:ltr:first-child, #dashtodockContainer.bottom #dash .dash-item-container:rtl:last-child {
      margin-left: 0; }
    #dashtodockContainer.bottom #dash .dash-item-container:ltr:last-child, #dashtodockContainer.bottom #dash .dash-item-container:rtl:first-child {
      margin-right: 0; }
    #dashtodockContainer.bottom #dash .dash-item-container .app-well-app,
    #dashtodockContainer.bottom #dash .dash-item-container .show-apps,
    #dashtodockContainer.bottom #dash .dash-item-container .overview-tile {
      padding: 2px 2px;
      padding-bottom: 14px;
      padding-top: 10px; }
      #dashtodockContainer.bottom #dash .dash-item-container .app-well-app:ltr:first-child, #dashtodockContainer.bottom #dash .dash-item-container .app-well-app:rtl:last-child,
      #dashtodockContainer.bottom #dash .dash-item-container .show-apps:ltr:first-child,
      #dashtodockContainer.bottom #dash .dash-item-container .show-apps:rtl:last-child,
      #dashtodockContainer.bottom #dash .dash-item-container .overview-tile:ltr:first-child,
      #dashtodockContainer.bottom #dash .dash-item-container .overview-tile:rtl:last-child {
        padding-left: 0; }
      #dashtodockContainer.bottom #dash .dash-item-container .app-well-app:ltr:last-child, #dashtodockContainer.bottom #dash .dash-item-container .app-well-app:rtl:first-child,
      #dashtodockContainer.bottom #dash .dash-item-container .show-apps:ltr:last-child,
      #dashtodockContainer.bottom #dash .dash-item-container .show-apps:rtl:first-child,
      #dashtodockContainer.bottom #dash .dash-item-container .overview-tile:ltr:last-child,
      #dashtodockContainer.bottom #dash .dash-item-container .overview-tile:rtl:first-child {
        padding-right: 0; }
      #dashtodockContainer.bottom #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.bottom #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.bottom #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.bottom #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.bottom #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.bottom #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.bottom #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.bottom #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.bottom #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.bottom #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.bottom #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.bottom #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.bottom.fixed #dash .dash-background {
  margin-top: 4px; }

#dashtodockContainer.bottom.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.bottom.fixed #dash .dash-item-container .show-apps {
  padding-top: 14px; }

.dash-label.bottom {
  margin-bottom: 10px;
  -x-offset: 0;
  -y-offset: 0; }

#dashtodockContainer.bottom.shrink #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.bottom.shrink #dash .dash-background {
    margin: 0;
    margin-bottom: 4px;
    padding: 0;
    border-radius: 18px;
    spacing: 2px; }
  #dashtodockContainer.bottom.shrink #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    margin: 0 1px;
    width: 1px;
    height: 0;
    margin-bottom: 4px; }
  #dashtodockContainer.bottom.shrink #dash #dashtodockDashContainer {
    padding: 3px;
    padding-bottom: 0;
    padding-top: 0; }
  #dashtodockContainer.bottom.shrink #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 0 2px; }
    #dashtodockContainer.bottom.shrink #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.bottom.shrink #dash .dash-item-container:ltr:first-child, #dashtodockContainer.bottom.shrink #dash .dash-item-container:rtl:last-child {
      margin-left: 0; }
    #dashtodockContainer.bottom.shrink #dash .dash-item-container:ltr:last-child, #dashtodockContainer.bottom.shrink #dash .dash-item-container:rtl:first-child {
      margin-right: 0; }
    #dashtodockContainer.bottom.shrink #dash .dash-item-container .app-well-app,
    #dashtodockContainer.bottom.shrink #dash .dash-item-container .show-apps,
    #dashtodockContainer.bottom.shrink #dash .dash-item-container .overview-tile {
      padding: 1px 1px;
      padding-bottom: 7px;
      padding-top: 3px; }
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .app-well-app:ltr:first-child, #dashtodockContainer.bottom.shrink #dash .dash-item-container .app-well-app:rtl:last-child,
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .show-apps:ltr:first-child,
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .show-apps:rtl:last-child,
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .overview-tile:ltr:first-child,
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .overview-tile:rtl:last-child {
        padding-left: 0; }
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .app-well-app:ltr:last-child, #dashtodockContainer.bottom.shrink #dash .dash-item-container .app-well-app:rtl:first-child,
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .show-apps:ltr:last-child,
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .show-apps:rtl:first-child,
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .overview-tile:ltr:last-child,
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .overview-tile:rtl:first-child {
        padding-right: 0; }
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.bottom.shrink #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.bottom.shrink #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.bottom.shrink #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.bottom.shrink #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.bottom.shrink #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.bottom.shrink #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.bottom.shrink #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.bottom.shrink #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.bottom.shrink #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.bottom.shrink #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.bottom.shrink.fixed #dash .dash-background {
  margin-top: 1px; }

#dashtodockContainer.bottom.shrink.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.bottom.shrink.fixed #dash .dash-item-container .show-apps {
  padding-top: 4px; }

.dash-label.bottom.shrink {
  margin-bottom: 3px;
  -x-offset: 0;
  -y-offset: 0; }

#dashtodockContainer.bottom.extended #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.bottom.extended #dash .dash-background {
    margin: 0;
    margin-bottom: 0;
    padding: 0;
    border-radius: 0;
    spacing: 6px; }
  #dashtodockContainer.bottom.extended #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    margin: 0 4px;
    width: 1px;
    height: 0;
    margin-bottom: 0; }
  #dashtodockContainer.bottom.extended #dash #dashtodockDashContainer {
    padding: 0;
    padding-bottom: 0;
    padding-top: 0; }
    #dashtodockContainer.bottom.extended #dash #dashtodockDashContainer > :first-child .show-apps {
      padding-left: 8px; }
    #dashtodockContainer.bottom.extended #dash #dashtodockDashContainer #dashtodockDashScrollview:first-child {
      padding-left: 8px; }
    #dashtodockContainer.bottom.extended #dash #dashtodockDashContainer > :last-child .show-apps {
      padding-right: 8px; }
    #dashtodockContainer.bottom.extended #dash #dashtodockDashContainer #dashtodockDashScrollview:last-child {
      padding-right: 8px; }
  #dashtodockContainer.bottom.extended #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 0 2px; }
    #dashtodockContainer.bottom.extended #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.bottom.extended #dash .dash-item-container:ltr:first-child, #dashtodockContainer.bottom.extended #dash .dash-item-container:rtl:last-child {
      margin-left: 0; }
    #dashtodockContainer.bottom.extended #dash .dash-item-container:ltr:last-child, #dashtodockContainer.bottom.extended #dash .dash-item-container:rtl:first-child {
      margin-right: 0; }
    #dashtodockContainer.bottom.extended #dash .dash-item-container .app-well-app,
    #dashtodockContainer.bottom.extended #dash .dash-item-container .show-apps,
    #dashtodockContainer.bottom.extended #dash .dash-item-container .overview-tile {
      padding: 2px 2px;
      padding-bottom: 10px;
      padding-top: 10px; }
      #dashtodockContainer.bottom.extended #dash .dash-item-container .app-well-app:ltr:first-child, #dashtodockContainer.bottom.extended #dash .dash-item-container .app-well-app:rtl:last-child,
      #dashtodockContainer.bottom.extended #dash .dash-item-container .show-apps:ltr:first-child,
      #dashtodockContainer.bottom.extended #dash .dash-item-container .show-apps:rtl:last-child,
      #dashtodockContainer.bottom.extended #dash .dash-item-container .overview-tile:ltr:first-child,
      #dashtodockContainer.bottom.extended #dash .dash-item-container .overview-tile:rtl:last-child {
        padding-left: 0; }
      #dashtodockContainer.bottom.extended #dash .dash-item-container .app-well-app:ltr:last-child, #dashtodockContainer.bottom.extended #dash .dash-item-container .app-well-app:rtl:first-child,
      #dashtodockContainer.bottom.extended #dash .dash-item-container .show-apps:ltr:last-child,
      #dashtodockContainer.bottom.extended #dash .dash-item-container .show-apps:rtl:first-child,
      #dashtodockContainer.bottom.extended #dash .dash-item-container .overview-tile:ltr:last-child,
      #dashtodockContainer.bottom.extended #dash .dash-item-container .overview-tile:rtl:first-child {
        padding-right: 0; }
      #dashtodockContainer.bottom.extended #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.bottom.extended #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.bottom.extended #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.bottom.extended #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.bottom.extended #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.bottom.extended #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.bottom.extended #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.bottom.extended #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.bottom.extended #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.bottom.extended #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.bottom.extended #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.bottom.extended #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.bottom.extended.fixed #dash .dash-background {
  margin-top: 0; }

#dashtodockContainer.bottom.extended.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.bottom.extended.fixed #dash .dash-item-container .show-apps {
  padding-top: 10px; }

.dash-label.bottom {
  margin-bottom: 10px;
  -x-offset: 0;
  -y-offset: 0; }

#dashtodockContainer.bottom.extended.shrink #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.bottom.extended.shrink #dash .dash-background {
    margin: 0;
    margin-bottom: 0;
    padding: 0;
    border-radius: 0;
    spacing: 2px; }
  #dashtodockContainer.bottom.extended.shrink #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    margin: 0 1px;
    width: 1px;
    height: 0;
    margin-bottom: 0; }
  #dashtodockContainer.bottom.extended.shrink #dash #dashtodockDashContainer {
    padding: 0;
    padding-bottom: 0;
    padding-top: 0; }
    #dashtodockContainer.bottom.extended.shrink #dash #dashtodockDashContainer > :first-child .show-apps {
      padding-left: 6px; }
    #dashtodockContainer.bottom.extended.shrink #dash #dashtodockDashContainer #dashtodockDashScrollview:first-child {
      padding-left: 6px; }
    #dashtodockContainer.bottom.extended.shrink #dash #dashtodockDashContainer > :last-child .show-apps {
      padding-right: 6px; }
    #dashtodockContainer.bottom.extended.shrink #dash #dashtodockDashContainer #dashtodockDashScrollview:last-child {
      padding-right: 6px; }
  #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 0 2px; }
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container:ltr:first-child, #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container:rtl:last-child {
      margin-left: 0; }
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container:ltr:last-child, #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container:rtl:first-child {
      margin-right: 0; }
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .app-well-app,
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .show-apps,
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .overview-tile {
      padding: 1px 1px;
      padding-bottom: 3px;
      padding-top: 3px; }
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .app-well-app:ltr:first-child, #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .app-well-app:rtl:last-child,
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .show-apps:ltr:first-child,
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .show-apps:rtl:last-child,
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .overview-tile:ltr:first-child,
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .overview-tile:rtl:last-child {
        padding-left: 0; }
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .app-well-app:ltr:last-child, #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .app-well-app:rtl:first-child,
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .show-apps:ltr:last-child,
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .show-apps:rtl:first-child,
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .overview-tile:ltr:last-child,
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .overview-tile:rtl:first-child {
        padding-right: 0; }
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.bottom.extended.shrink #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.bottom.extended.shrink.fixed #dash .dash-background {
  margin-top: 0; }

#dashtodockContainer.bottom.extended.shrink.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.bottom.extended.shrink.fixed #dash .dash-item-container .show-apps {
  padding-top: 3px; }

.dash-label.bottom.shrink {
  margin-bottom: 3px;
  -x-offset: 0;
  -y-offset: 0; }

.dashtodock-app-well-preview-menu-item.bottom {
  padding: 0.5em 0.5em; }
  .dashtodock-app-well-preview-menu-item.bottom:ltr:first-child, .dashtodock-app-well-preview-menu-item.bottom:rtl:last-child {
    padding-left: 1em; }
  .dashtodock-app-well-preview-menu-item.bottom:ltr:last-child, .dashtodock-app-well-preview-menu-item.bottom:rtl:first-child {
    padding-right: 1em; }

#dashtodockContainer.top #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.top #dash .dash-background {
    margin: 0;
    margin-top: 4px;
    padding: 0;
    border-radius: 24px;
    spacing: 6px; }
  #dashtodockContainer.top #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    margin: 0 4px;
    width: 1px;
    height: 0;
    margin-top: 4px; }
  #dashtodockContainer.top #dash #dashtodockDashContainer {
    padding: 10px;
    padding-top: 0;
    padding-bottom: 0; }
  #dashtodockContainer.top #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 0 2px; }
    #dashtodockContainer.top #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.top #dash .dash-item-container:ltr:first-child, #dashtodockContainer.top #dash .dash-item-container:rtl:last-child {
      margin-left: 0; }
    #dashtodockContainer.top #dash .dash-item-container:ltr:last-child, #dashtodockContainer.top #dash .dash-item-container:rtl:first-child {
      margin-right: 0; }
    #dashtodockContainer.top #dash .dash-item-container .app-well-app,
    #dashtodockContainer.top #dash .dash-item-container .show-apps,
    #dashtodockContainer.top #dash .dash-item-container .overview-tile {
      padding: 2px 2px;
      padding-top: 14px;
      padding-bottom: 10px; }
      #dashtodockContainer.top #dash .dash-item-container .app-well-app:ltr:first-child, #dashtodockContainer.top #dash .dash-item-container .app-well-app:rtl:last-child,
      #dashtodockContainer.top #dash .dash-item-container .show-apps:ltr:first-child,
      #dashtodockContainer.top #dash .dash-item-container .show-apps:rtl:last-child,
      #dashtodockContainer.top #dash .dash-item-container .overview-tile:ltr:first-child,
      #dashtodockContainer.top #dash .dash-item-container .overview-tile:rtl:last-child {
        padding-left: 0; }
      #dashtodockContainer.top #dash .dash-item-container .app-well-app:ltr:last-child, #dashtodockContainer.top #dash .dash-item-container .app-well-app:rtl:first-child,
      #dashtodockContainer.top #dash .dash-item-container .show-apps:ltr:last-child,
      #dashtodockContainer.top #dash .dash-item-container .show-apps:rtl:first-child,
      #dashtodockContainer.top #dash .dash-item-container .overview-tile:ltr:last-child,
      #dashtodockContainer.top #dash .dash-item-container .overview-tile:rtl:first-child {
        padding-right: 0; }
      #dashtodockContainer.top #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.top #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.top #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.top #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.top #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.top #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.top #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.top #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.top #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.top #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.top #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.top #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.top.fixed #dash .dash-background {
  margin-bottom: 4px; }

#dashtodockContainer.top.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.top.fixed #dash .dash-item-container .show-apps {
  padding-bottom: 14px; }

.dash-label.top {
  margin-top: 10px;
  -x-offset: 0;
  -y-offset: 0; }

#dashtodockContainer.top.shrink #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.top.shrink #dash .dash-background {
    margin: 0;
    margin-top: 4px;
    padding: 0;
    border-radius: 18px;
    spacing: 2px; }
  #dashtodockContainer.top.shrink #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    margin: 0 1px;
    width: 1px;
    height: 0;
    margin-top: 4px; }
  #dashtodockContainer.top.shrink #dash #dashtodockDashContainer {
    padding: 3px;
    padding-top: 0;
    padding-bottom: 0; }
  #dashtodockContainer.top.shrink #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 0 2px; }
    #dashtodockContainer.top.shrink #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.top.shrink #dash .dash-item-container:ltr:first-child, #dashtodockContainer.top.shrink #dash .dash-item-container:rtl:last-child {
      margin-left: 0; }
    #dashtodockContainer.top.shrink #dash .dash-item-container:ltr:last-child, #dashtodockContainer.top.shrink #dash .dash-item-container:rtl:first-child {
      margin-right: 0; }
    #dashtodockContainer.top.shrink #dash .dash-item-container .app-well-app,
    #dashtodockContainer.top.shrink #dash .dash-item-container .show-apps,
    #dashtodockContainer.top.shrink #dash .dash-item-container .overview-tile {
      padding: 1px 1px;
      padding-top: 7px;
      padding-bottom: 3px; }
      #dashtodockContainer.top.shrink #dash .dash-item-container .app-well-app:ltr:first-child, #dashtodockContainer.top.shrink #dash .dash-item-container .app-well-app:rtl:last-child,
      #dashtodockContainer.top.shrink #dash .dash-item-container .show-apps:ltr:first-child,
      #dashtodockContainer.top.shrink #dash .dash-item-container .show-apps:rtl:last-child,
      #dashtodockContainer.top.shrink #dash .dash-item-container .overview-tile:ltr:first-child,
      #dashtodockContainer.top.shrink #dash .dash-item-container .overview-tile:rtl:last-child {
        padding-left: 0; }
      #dashtodockContainer.top.shrink #dash .dash-item-container .app-well-app:ltr:last-child, #dashtodockContainer.top.shrink #dash .dash-item-container .app-well-app:rtl:first-child,
      #dashtodockContainer.top.shrink #dash .dash-item-container .show-apps:ltr:last-child,
      #dashtodockContainer.top.shrink #dash .dash-item-container .show-apps:rtl:first-child,
      #dashtodockContainer.top.shrink #dash .dash-item-container .overview-tile:ltr:last-child,
      #dashtodockContainer.top.shrink #dash .dash-item-container .overview-tile:rtl:first-child {
        padding-right: 0; }
      #dashtodockContainer.top.shrink #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.top.shrink #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.top.shrink #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.top.shrink #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.top.shrink #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.top.shrink #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.top.shrink #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.top.shrink #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.top.shrink #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.top.shrink #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.top.shrink #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.top.shrink #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.top.shrink.fixed #dash .dash-background {
  margin-bottom: 1px; }

#dashtodockContainer.top.shrink.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.top.shrink.fixed #dash .dash-item-container .show-apps {
  padding-bottom: 4px; }

.dash-label.top.shrink {
  margin-top: 3px;
  -x-offset: 0;
  -y-offset: 0; }

#dashtodockContainer.top.extended #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.top.extended #dash .dash-background {
    margin: 0;
    margin-top: 0;
    padding: 0;
    border-radius: 0;
    spacing: 6px; }
  #dashtodockContainer.top.extended #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    margin: 0 4px;
    width: 1px;
    height: 0;
    margin-top: 0; }
  #dashtodockContainer.top.extended #dash #dashtodockDashContainer {
    padding: 0;
    padding-top: 0;
    padding-bottom: 0; }
    #dashtodockContainer.top.extended #dash #dashtodockDashContainer > :first-child .show-apps {
      padding-left: 8px; }
    #dashtodockContainer.top.extended #dash #dashtodockDashContainer #dashtodockDashScrollview:first-child {
      padding-left: 8px; }
    #dashtodockContainer.top.extended #dash #dashtodockDashContainer > :last-child .show-apps {
      padding-right: 8px; }
    #dashtodockContainer.top.extended #dash #dashtodockDashContainer #dashtodockDashScrollview:last-child {
      padding-right: 8px; }
  #dashtodockContainer.top.extended #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 0 2px; }
    #dashtodockContainer.top.extended #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.top.extended #dash .dash-item-container:ltr:first-child, #dashtodockContainer.top.extended #dash .dash-item-container:rtl:last-child {
      margin-left: 0; }
    #dashtodockContainer.top.extended #dash .dash-item-container:ltr:last-child, #dashtodockContainer.top.extended #dash .dash-item-container:rtl:first-child {
      margin-right: 0; }
    #dashtodockContainer.top.extended #dash .dash-item-container .app-well-app,
    #dashtodockContainer.top.extended #dash .dash-item-container .show-apps,
    #dashtodockContainer.top.extended #dash .dash-item-container .overview-tile {
      padding: 2px 2px;
      padding-top: 10px;
      padding-bottom: 10px; }
      #dashtodockContainer.top.extended #dash .dash-item-container .app-well-app:ltr:first-child, #dashtodockContainer.top.extended #dash .dash-item-container .app-well-app:rtl:last-child,
      #dashtodockContainer.top.extended #dash .dash-item-container .show-apps:ltr:first-child,
      #dashtodockContainer.top.extended #dash .dash-item-container .show-apps:rtl:last-child,
      #dashtodockContainer.top.extended #dash .dash-item-container .overview-tile:ltr:first-child,
      #dashtodockContainer.top.extended #dash .dash-item-container .overview-tile:rtl:last-child {
        padding-left: 0; }
      #dashtodockContainer.top.extended #dash .dash-item-container .app-well-app:ltr:last-child, #dashtodockContainer.top.extended #dash .dash-item-container .app-well-app:rtl:first-child,
      #dashtodockContainer.top.extended #dash .dash-item-container .show-apps:ltr:last-child,
      #dashtodockContainer.top.extended #dash .dash-item-container .show-apps:rtl:first-child,
      #dashtodockContainer.top.extended #dash .dash-item-container .overview-tile:ltr:last-child,
      #dashtodockContainer.top.extended #dash .dash-item-container .overview-tile:rtl:first-child {
        padding-right: 0; }
      #dashtodockContainer.top.extended #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.top.extended #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.top.extended #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.top.extended #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.top.extended #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.top.extended #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.top.extended #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.top.extended #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.top.extended #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.top.extended #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.top.extended #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.top.extended #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.top.extended.fixed #dash .dash-background {
  margin-bottom: 0; }

#dashtodockContainer.top.extended.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.top.extended.fixed #dash .dash-item-container .show-apps {
  padding-bottom: 10px; }

.dash-label.top {
  margin-top: 10px;
  -x-offset: 0;
  -y-offset: 0; }

#dashtodockContainer.top.extended.shrink #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.top.extended.shrink #dash .dash-background {
    margin: 0;
    margin-top: 0;
    padding: 0;
    border-radius: 0;
    spacing: 2px; }
  #dashtodockContainer.top.extended.shrink #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    margin: 0 1px;
    width: 1px;
    height: 0;
    margin-top: 0; }
  #dashtodockContainer.top.extended.shrink #dash #dashtodockDashContainer {
    padding: 0;
    padding-top: 0;
    padding-bottom: 0; }
    #dashtodockContainer.top.extended.shrink #dash #dashtodockDashContainer > :first-child .show-apps {
      padding-left: 6px; }
    #dashtodockContainer.top.extended.shrink #dash #dashtodockDashContainer #dashtodockDashScrollview:first-child {
      padding-left: 6px; }
    #dashtodockContainer.top.extended.shrink #dash #dashtodockDashContainer > :last-child .show-apps {
      padding-right: 6px; }
    #dashtodockContainer.top.extended.shrink #dash #dashtodockDashContainer #dashtodockDashScrollview:last-child {
      padding-right: 6px; }
  #dashtodockContainer.top.extended.shrink #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 0 2px; }
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container:ltr:first-child, #dashtodockContainer.top.extended.shrink #dash .dash-item-container:rtl:last-child {
      margin-left: 0; }
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container:ltr:last-child, #dashtodockContainer.top.extended.shrink #dash .dash-item-container:rtl:first-child {
      margin-right: 0; }
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container .app-well-app,
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container .show-apps,
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container .overview-tile {
      padding: 1px 1px;
      padding-top: 3px;
      padding-bottom: 3px; }
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .app-well-app:ltr:first-child, #dashtodockContainer.top.extended.shrink #dash .dash-item-container .app-well-app:rtl:last-child,
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .show-apps:ltr:first-child,
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .show-apps:rtl:last-child,
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .overview-tile:ltr:first-child,
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .overview-tile:rtl:last-child {
        padding-left: 0; }
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .app-well-app:ltr:last-child, #dashtodockContainer.top.extended.shrink #dash .dash-item-container .app-well-app:rtl:first-child,
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .show-apps:ltr:last-child,
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .show-apps:rtl:first-child,
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .overview-tile:ltr:last-child,
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .overview-tile:rtl:first-child {
        padding-right: 0; }
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.top.extended.shrink #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.top.extended.shrink #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.top.extended.shrink.fixed #dash .dash-background {
  margin-bottom: 0; }

#dashtodockContainer.top.extended.shrink.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.top.extended.shrink.fixed #dash .dash-item-container .show-apps {
  padding-bottom: 3px; }

.dash-label.top.shrink {
  margin-top: 3px;
  -x-offset: 0;
  -y-offset: 0; }

.dashtodock-app-well-preview-menu-item.top {
  padding: 0.5em 0.5em; }
  .dashtodock-app-well-preview-menu-item.top:ltr:first-child, .dashtodock-app-well-preview-menu-item.top:rtl:last-child {
    padding-left: 1em; }
  .dashtodock-app-well-preview-menu-item.top:ltr:last-child, .dashtodock-app-well-preview-menu-item.top:rtl:first-child {
    padding-right: 1em; }

#dashtodockContainer.left #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.left #dash .dash-background {
    margin: 0;
    margin-left: 4px;
    padding: 0;
    border-radius: 24px;
    spacing: 6px; }
  #dashtodockContainer.left #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    width: 0;
    height: 1px;
    margin: 4px 0;
    margin-left: 4px; }
  #dashtodockContainer.left #dash #dashtodockDashContainer {
    padding: 10px;
    padding-left: 0;
    padding-right: 0; }
  #dashtodockContainer.left #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 2px 0; }
    #dashtodockContainer.left #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.left #dash .dash-item-container:first-child {
      margin-top: 0; }
    #dashtodockContainer.left #dash .dash-item-container:last-child {
      margin-bottom: 0; }
    #dashtodockContainer.left #dash .dash-item-container .app-well-app,
    #dashtodockContainer.left #dash .dash-item-container .show-apps,
    #dashtodockContainer.left #dash .dash-item-container .overview-tile {
      padding: 2px 2px;
      padding-left: 14px;
      padding-right: 10px; }
      #dashtodockContainer.left #dash .dash-item-container .app-well-app:first-child,
      #dashtodockContainer.left #dash .dash-item-container .show-apps:first-child,
      #dashtodockContainer.left #dash .dash-item-container .overview-tile:first-child {
        padding-top: 0; }
      #dashtodockContainer.left #dash .dash-item-container .app-well-app:last-child,
      #dashtodockContainer.left #dash .dash-item-container .show-apps:last-child,
      #dashtodockContainer.left #dash .dash-item-container .overview-tile:last-child {
        padding-bottom: 0; }
      #dashtodockContainer.left #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.left #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.left #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.left #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.left #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.left #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.left #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.left #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.left #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.left #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.left #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.left #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.left.fixed #dash .dash-background {
  margin-right: 4px; }

#dashtodockContainer.left.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.left.fixed #dash .dash-item-container .show-apps {
  padding-right: 14px; }

.dash-label.left {
  margin: 0;
  -x-offset: 10px;
  -y-offset: 0; }

#dashtodockContainer.left.shrink #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.left.shrink #dash .dash-background {
    margin: 0;
    margin-left: 4px;
    padding: 0;
    border-radius: 18px;
    spacing: 2px; }
  #dashtodockContainer.left.shrink #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    width: 0;
    height: 1px;
    margin: 1px 0;
    margin-left: 4px; }
  #dashtodockContainer.left.shrink #dash #dashtodockDashContainer {
    padding: 3px;
    padding-left: 0;
    padding-right: 0; }
  #dashtodockContainer.left.shrink #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 2px 0; }
    #dashtodockContainer.left.shrink #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.left.shrink #dash .dash-item-container:first-child {
      margin-top: 0; }
    #dashtodockContainer.left.shrink #dash .dash-item-container:last-child {
      margin-bottom: 0; }
    #dashtodockContainer.left.shrink #dash .dash-item-container .app-well-app,
    #dashtodockContainer.left.shrink #dash .dash-item-container .show-apps,
    #dashtodockContainer.left.shrink #dash .dash-item-container .overview-tile {
      padding: 1px 1px;
      padding-left: 7px;
      padding-right: 3px; }
      #dashtodockContainer.left.shrink #dash .dash-item-container .app-well-app:first-child,
      #dashtodockContainer.left.shrink #dash .dash-item-container .show-apps:first-child,
      #dashtodockContainer.left.shrink #dash .dash-item-container .overview-tile:first-child {
        padding-top: 0; }
      #dashtodockContainer.left.shrink #dash .dash-item-container .app-well-app:last-child,
      #dashtodockContainer.left.shrink #dash .dash-item-container .show-apps:last-child,
      #dashtodockContainer.left.shrink #dash .dash-item-container .overview-tile:last-child {
        padding-bottom: 0; }
      #dashtodockContainer.left.shrink #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.left.shrink #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.left.shrink #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.left.shrink #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.left.shrink #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.left.shrink #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.left.shrink #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.left.shrink #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.left.shrink #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.left.shrink #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.left.shrink #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.left.shrink #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.left.shrink.fixed #dash .dash-background {
  margin-right: 1px; }

#dashtodockContainer.left.shrink.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.left.shrink.fixed #dash .dash-item-container .show-apps {
  padding-right: 4px; }

.dash-label.left.shrink {
  margin: 0;
  -x-offset: 3px;
  -y-offset: 0; }

#dashtodockContainer.left.extended #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.left.extended #dash .dash-background {
    margin: 0;
    margin-left: 0;
    padding: 0;
    border-radius: 0;
    spacing: 6px; }
  #dashtodockContainer.left.extended #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    width: 0;
    height: 1px;
    margin: 4px 0;
    margin-left: 0; }
  #dashtodockContainer.left.extended #dash #dashtodockDashContainer {
    padding: 0;
    padding-left: 0;
    padding-right: 0; }
    #dashtodockContainer.left.extended #dash #dashtodockDashContainer > :first-child .show-apps {
      padding-top: 8px; }
    #dashtodockContainer.left.extended #dash #dashtodockDashContainer #dashtodockDashScrollview:first-child {
      padding-top: 8px; }
    #dashtodockContainer.left.extended #dash #dashtodockDashContainer > :last-child .show-apps {
      padding-bottom: 8px; }
    #dashtodockContainer.left.extended #dash #dashtodockDashContainer #dashtodockDashScrollview:last-child {
      padding-bottom: 8px; }
  #dashtodockContainer.left.extended #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 2px 0; }
    #dashtodockContainer.left.extended #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.left.extended #dash .dash-item-container:first-child {
      margin-top: 0; }
    #dashtodockContainer.left.extended #dash .dash-item-container:last-child {
      margin-bottom: 0; }
    #dashtodockContainer.left.extended #dash .dash-item-container .app-well-app,
    #dashtodockContainer.left.extended #dash .dash-item-container .show-apps,
    #dashtodockContainer.left.extended #dash .dash-item-container .overview-tile {
      padding: 2px 2px;
      padding-left: 10px;
      padding-right: 10px; }
      #dashtodockContainer.left.extended #dash .dash-item-container .app-well-app:first-child,
      #dashtodockContainer.left.extended #dash .dash-item-container .show-apps:first-child,
      #dashtodockContainer.left.extended #dash .dash-item-container .overview-tile:first-child {
        padding-top: 0; }
      #dashtodockContainer.left.extended #dash .dash-item-container .app-well-app:last-child,
      #dashtodockContainer.left.extended #dash .dash-item-container .show-apps:last-child,
      #dashtodockContainer.left.extended #dash .dash-item-container .overview-tile:last-child {
        padding-bottom: 0; }
      #dashtodockContainer.left.extended #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.left.extended #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.left.extended #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.left.extended #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.left.extended #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.left.extended #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.left.extended #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.left.extended #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.left.extended #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.left.extended #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.left.extended #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.left.extended #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.left.extended.fixed #dash .dash-background {
  margin-right: 0; }

#dashtodockContainer.left.extended.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.left.extended.fixed #dash .dash-item-container .show-apps {
  padding-right: 10px; }

.dash-label.left {
  margin: 0;
  -x-offset: 10px;
  -y-offset: 0; }

#dashtodockContainer.left.extended.shrink #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.left.extended.shrink #dash .dash-background {
    margin: 0;
    margin-left: 0;
    padding: 0;
    border-radius: 0;
    spacing: 2px; }
  #dashtodockContainer.left.extended.shrink #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    width: 0;
    height: 1px;
    margin: 1px 0;
    margin-left: 0; }
  #dashtodockContainer.left.extended.shrink #dash #dashtodockDashContainer {
    padding: 0;
    padding-left: 0;
    padding-right: 0; }
    #dashtodockContainer.left.extended.shrink #dash #dashtodockDashContainer > :first-child .show-apps {
      padding-top: 6px; }
    #dashtodockContainer.left.extended.shrink #dash #dashtodockDashContainer #dashtodockDashScrollview:first-child {
      padding-top: 6px; }
    #dashtodockContainer.left.extended.shrink #dash #dashtodockDashContainer > :last-child .show-apps {
      padding-bottom: 6px; }
    #dashtodockContainer.left.extended.shrink #dash #dashtodockDashContainer #dashtodockDashScrollview:last-child {
      padding-bottom: 6px; }
  #dashtodockContainer.left.extended.shrink #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 2px 0; }
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container:first-child {
      margin-top: 0; }
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container:last-child {
      margin-bottom: 0; }
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container .app-well-app,
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container .show-apps,
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container .overview-tile {
      padding: 1px 1px;
      padding-left: 3px;
      padding-right: 3px; }
      #dashtodockContainer.left.extended.shrink #dash .dash-item-container .app-well-app:first-child,
      #dashtodockContainer.left.extended.shrink #dash .dash-item-container .show-apps:first-child,
      #dashtodockContainer.left.extended.shrink #dash .dash-item-container .overview-tile:first-child {
        padding-top: 0; }
      #dashtodockContainer.left.extended.shrink #dash .dash-item-container .app-well-app:last-child,
      #dashtodockContainer.left.extended.shrink #dash .dash-item-container .show-apps:last-child,
      #dashtodockContainer.left.extended.shrink #dash .dash-item-container .overview-tile:last-child {
        padding-bottom: 0; }
      #dashtodockContainer.left.extended.shrink #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.left.extended.shrink #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.left.extended.shrink #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.left.extended.shrink #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.left.extended.shrink.fixed #dash .dash-background {
  margin-right: 0; }

#dashtodockContainer.left.extended.shrink.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.left.extended.shrink.fixed #dash .dash-item-container .show-apps {
  padding-right: 3px; }

.dash-label.left.shrink {
  margin: 0;
  -x-offset: 3px;
  -y-offset: 0; }

.dashtodock-app-well-preview-menu-item.left {
  padding: 0.5em 0.5em; }
  .dashtodock-app-well-preview-menu-item.left:first-child {
    padding-top: 1em; }
  .dashtodock-app-well-preview-menu-item.left:last-child {
    padding-bottom: 1em; }

#dashtodockContainer.right #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.right #dash .dash-background {
    margin: 0;
    margin-right: 4px;
    padding: 0;
    border-radius: 24px;
    spacing: 6px; }
  #dashtodockContainer.right #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    width: 0;
    height: 1px;
    margin: 4px 0;
    margin-right: 4px; }
  #dashtodockContainer.right #dash #dashtodockDashContainer {
    padding: 10px;
    padding-right: 0;
    padding-left: 0; }
  #dashtodockContainer.right #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 2px 0; }
    #dashtodockContainer.right #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.right #dash .dash-item-container:first-child {
      margin-top: 0; }
    #dashtodockContainer.right #dash .dash-item-container:last-child {
      margin-bottom: 0; }
    #dashtodockContainer.right #dash .dash-item-container .app-well-app,
    #dashtodockContainer.right #dash .dash-item-container .show-apps,
    #dashtodockContainer.right #dash .dash-item-container .overview-tile {
      padding: 2px 2px;
      padding-right: 14px;
      padding-left: 10px; }
      #dashtodockContainer.right #dash .dash-item-container .app-well-app:first-child,
      #dashtodockContainer.right #dash .dash-item-container .show-apps:first-child,
      #dashtodockContainer.right #dash .dash-item-container .overview-tile:first-child {
        padding-top: 0; }
      #dashtodockContainer.right #dash .dash-item-container .app-well-app:last-child,
      #dashtodockContainer.right #dash .dash-item-container .show-apps:last-child,
      #dashtodockContainer.right #dash .dash-item-container .overview-tile:last-child {
        padding-bottom: 0; }
      #dashtodockContainer.right #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.right #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.right #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.right #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.right #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.right #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.right #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.right #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.right #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.right #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.right #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.right #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.right.fixed #dash .dash-background {
  margin-left: 4px; }

#dashtodockContainer.right.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.right.fixed #dash .dash-item-container .show-apps {
  padding-left: 14px; }

.dash-label.right {
  margin: 0;
  -x-offset: 10px;
  -y-offset: 0; }

#dashtodockContainer.right.shrink #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.right.shrink #dash .dash-background {
    margin: 0;
    margin-right: 4px;
    padding: 0;
    border-radius: 18px;
    spacing: 2px; }
  #dashtodockContainer.right.shrink #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    width: 0;
    height: 1px;
    margin: 1px 0;
    margin-right: 4px; }
  #dashtodockContainer.right.shrink #dash #dashtodockDashContainer {
    padding: 3px;
    padding-right: 0;
    padding-left: 0; }
  #dashtodockContainer.right.shrink #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 2px 0; }
    #dashtodockContainer.right.shrink #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.right.shrink #dash .dash-item-container:first-child {
      margin-top: 0; }
    #dashtodockContainer.right.shrink #dash .dash-item-container:last-child {
      margin-bottom: 0; }
    #dashtodockContainer.right.shrink #dash .dash-item-container .app-well-app,
    #dashtodockContainer.right.shrink #dash .dash-item-container .show-apps,
    #dashtodockContainer.right.shrink #dash .dash-item-container .overview-tile {
      padding: 1px 1px;
      padding-right: 7px;
      padding-left: 3px; }
      #dashtodockContainer.right.shrink #dash .dash-item-container .app-well-app:first-child,
      #dashtodockContainer.right.shrink #dash .dash-item-container .show-apps:first-child,
      #dashtodockContainer.right.shrink #dash .dash-item-container .overview-tile:first-child {
        padding-top: 0; }
      #dashtodockContainer.right.shrink #dash .dash-item-container .app-well-app:last-child,
      #dashtodockContainer.right.shrink #dash .dash-item-container .show-apps:last-child,
      #dashtodockContainer.right.shrink #dash .dash-item-container .overview-tile:last-child {
        padding-bottom: 0; }
      #dashtodockContainer.right.shrink #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.right.shrink #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.right.shrink #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.right.shrink #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.right.shrink #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.right.shrink #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.right.shrink #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.right.shrink #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.right.shrink #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.right.shrink #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.right.shrink #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.right.shrink #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.right.shrink.fixed #dash .dash-background {
  margin-left: 1px; }

#dashtodockContainer.right.shrink.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.right.shrink.fixed #dash .dash-item-container .show-apps {
  padding-left: 4px; }

.dash-label.right.shrink {
  margin: 0;
  -x-offset: 3px;
  -y-offset: 0; }

#dashtodockContainer.right.extended #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.right.extended #dash .dash-background {
    margin: 0;
    margin-right: 0;
    padding: 0;
    border-radius: 0;
    spacing: 6px; }
  #dashtodockContainer.right.extended #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    width: 0;
    height: 1px;
    margin: 4px 0;
    margin-right: 0; }
  #dashtodockContainer.right.extended #dash #dashtodockDashContainer {
    padding: 0;
    padding-right: 0;
    padding-left: 0; }
    #dashtodockContainer.right.extended #dash #dashtodockDashContainer > :first-child .show-apps {
      padding-top: 8px; }
    #dashtodockContainer.right.extended #dash #dashtodockDashContainer #dashtodockDashScrollview:first-child {
      padding-top: 8px; }
    #dashtodockContainer.right.extended #dash #dashtodockDashContainer > :last-child .show-apps {
      padding-bottom: 8px; }
    #dashtodockContainer.right.extended #dash #dashtodockDashContainer #dashtodockDashScrollview:last-child {
      padding-bottom: 8px; }
  #dashtodockContainer.right.extended #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 2px 0; }
    #dashtodockContainer.right.extended #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.right.extended #dash .dash-item-container:first-child {
      margin-top: 0; }
    #dashtodockContainer.right.extended #dash .dash-item-container:last-child {
      margin-bottom: 0; }
    #dashtodockContainer.right.extended #dash .dash-item-container .app-well-app,
    #dashtodockContainer.right.extended #dash .dash-item-container .show-apps,
    #dashtodockContainer.right.extended #dash .dash-item-container .overview-tile {
      padding: 2px 2px;
      padding-right: 10px;
      padding-left: 10px; }
      #dashtodockContainer.right.extended #dash .dash-item-container .app-well-app:first-child,
      #dashtodockContainer.right.extended #dash .dash-item-container .show-apps:first-child,
      #dashtodockContainer.right.extended #dash .dash-item-container .overview-tile:first-child {
        padding-top: 0; }
      #dashtodockContainer.right.extended #dash .dash-item-container .app-well-app:last-child,
      #dashtodockContainer.right.extended #dash .dash-item-container .show-apps:last-child,
      #dashtodockContainer.right.extended #dash .dash-item-container .overview-tile:last-child {
        padding-bottom: 0; }
      #dashtodockContainer.right.extended #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.right.extended #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.right.extended #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.right.extended #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.right.extended #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.right.extended #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.right.extended #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.right.extended #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.right.extended #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.right.extended #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.right.extended #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.right.extended #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.right.extended.fixed #dash .dash-background {
  margin-left: 0; }

#dashtodockContainer.right.extended.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.right.extended.fixed #dash .dash-item-container .show-apps {
  padding-left: 10px; }

.dash-label.right {
  margin: 0;
  -x-offset: 10px;
  -y-offset: 0; }

#dashtodockContainer.right.extended.shrink #dash {
  margin: 0px;
  padding: 0px; }
  #dashtodockContainer.right.extended.shrink #dash .dash-background {
    margin: 0;
    margin-right: 0;
    padding: 0;
    border-radius: 0;
    spacing: 2px; }
  #dashtodockContainer.right.extended.shrink #dash .dash-separator {
    background-color: rgba(255, 255, 255, 0.1);
    width: 0;
    height: 1px;
    margin: 1px 0;
    margin-right: 0; }
  #dashtodockContainer.right.extended.shrink #dash #dashtodockDashContainer {
    padding: 0;
    padding-right: 0;
    padding-left: 0; }
    #dashtodockContainer.right.extended.shrink #dash #dashtodockDashContainer > :first-child .show-apps {
      padding-top: 6px; }
    #dashtodockContainer.right.extended.shrink #dash #dashtodockDashContainer #dashtodockDashScrollview:first-child {
      padding-top: 6px; }
    #dashtodockContainer.right.extended.shrink #dash #dashtodockDashContainer > :last-child .show-apps {
      padding-bottom: 6px; }
    #dashtodockContainer.right.extended.shrink #dash #dashtodockDashContainer #dashtodockDashScrollview:last-child {
      padding-bottom: 6px; }
  #dashtodockContainer.right.extended.shrink #dash .dash-item-container {
    /* Disable all margins defined upstream, we handle them here */
    margin: 2px 0; }
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container > * {
      margin: 0; }
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container:first-child {
      margin-top: 0; }
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container:last-child {
      margin-bottom: 0; }
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container .app-well-app,
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container .show-apps,
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container .overview-tile {
      padding: 1px 1px;
      padding-right: 3px;
      padding-left: 3px; }
      #dashtodockContainer.right.extended.shrink #dash .dash-item-container .app-well-app:first-child,
      #dashtodockContainer.right.extended.shrink #dash .dash-item-container .show-apps:first-child,
      #dashtodockContainer.right.extended.shrink #dash .dash-item-container .overview-tile:first-child {
        padding-top: 0; }
      #dashtodockContainer.right.extended.shrink #dash .dash-item-container .app-well-app:last-child,
      #dashtodockContainer.right.extended.shrink #dash .dash-item-container .show-apps:last-child,
      #dashtodockContainer.right.extended.shrink #dash .dash-item-container .overview-tile:last-child {
        padding-bottom: 0; }
      #dashtodockContainer.right.extended.shrink #dash .dash-item-container .app-well-app.updating,
      #dashtodockContainer.right.extended.shrink #dash .dash-item-container .show-apps.updating,
      #dashtodockContainer.right.extended.shrink #dash .dash-item-container .overview-tile.updating {
        opacity: 0.5; }
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container .app-well-app.running .overview-icon,
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container .overview-tile.running .overview-icon {
      background-image: none; }
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container .app-well-app.focused .overview-icon,
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container .overview-tile.focused .overview-icon {
      background-color: rgba(238, 238, 238, 0.2); }
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container .app-well-app .app-well-app-running-dot,
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container .app-well-app .app-grid-running-dot,
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container .overview-tile .app-well-app-running-dot,
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container .overview-tile .app-grid-running-dot {
      margin-bottom: 2px; }
    #dashtodockContainer.right.extended.shrink #dash .dash-item-container > StButton {
      transition-duration: 250;
      background-size: contain; }

#dashtodockContainer.right.extended.shrink.fixed #dash .dash-background {
  margin-left: 0; }

#dashtodockContainer.right.extended.shrink.fixed #dash .dash-item-container .app-well-app,
#dashtodockContainer.right.extended.shrink.fixed #dash .dash-item-container .show-apps {
  padding-left: 3px; }

.dash-label.right.shrink {
  margin: 0;
  -x-offset: 3px;
  -y-offset: 0; }

.dashtodock-app-well-preview-menu-item.right {
  padding: 0.5em 0.5em; }
  .dashtodock-app-well-preview-menu-item.right:first-child {
    padding-top: 1em; }
  .dashtodock-app-well-preview-menu-item.right:last-child {
    padding-bottom: 1em; }

#dashtodockContainer.top.shrink #dash .dash-background {
  margin-top: 4px;
  margin-bottom: 0; }

#dashtodockContainer.straight-corner #dash .dash-background,
#dashtodockContainer.shrink.straight-corner #dash .dash-background {
  border-radius: 0px; }

/* Scrollview style */
.bottom #dashtodockDashScrollview,
.top #dashtodockDashScrollview {
  -st-hfade-offset: 24px; }

.left #dashtodockDashScrollview,
.right #dashtodockDashScrollview {
  -st-vfade-offset: 24px; }

#dashtodockContainer.dashtodock #dash .dash-background {
  background: #303030; }

#dashtodockContainer.dashtodock .progress-bar,
.overview-tile .progress-bar,
.icon-grid .progress-bar {
  /* Customization of the progress bar style. The possible elements
     * are:
     *
     * -XXXXXX-YYYYYY: plain color
     * -XXXXXX-YYYYYY-color-start: start color for gradient
     * -XXXXXX-YYYYYY-color-end: end color for gradient
     * -XXXXXX-YYYYYY-offset-start: offset for start color in gradient (0-1)
     * -XXXXXX-YYYYYY-offset-end: offset for end color in gradient (0-1)
     * -XXXXXX-line-width: width value for the line used for the border
     *
     * XXXXXX can be either
     *
     *    progress-bar-track: the "track" over which the progress bar is shown
     *    progress-bar: the progress bar itself
     *
     * YYYYYY can be either
     *
     *    background: for the background color
     *    border: for the border color
     *
     * plain color entries have priority over gradients, so if both are set for
     * an element, the plain color will be used.
     *
     * Examples:
     *
     *  -progress-bar-track-background: rgba(128, 128, 0, 0.75);
     *  -progress-bar-track-border: rgba(0, 0, 255, 0.25);
     *
     *  -progress-bar-background: rgba(0, 204, 204, 1);
     *  -progress-bar-border: rgba(230, 230, 230, 1);
     *
     * Default values when these entries aren't set are equivalent to:
     *   -progress-bar-track-background-color-start: 64, 64, 64, 1.0
     *   -progress-bar-track-background-color-end: 89, 89, 89, 1.0
     *   -progress-bar-track-background-start-offset: 0.4
     *   -progress-bar-track-background-end-offset: 0.9
     *   -progress-bar-track-border-color-start: 128, 128, 128, 0.1
     *   -progress-bar-track-border-color-end: 89, 89, 89, 0.4
     *   -progress-bar-track-border-start-offset: 0.5
     *   -progress-bar-track-border-end-offset: 0.9
     *   -progress-bar-track-line-width: 1
     *   -progress-bar-background: 204, 204, 204, 1.0
     *   -progress-bar-border: 230, 230, 230, 1.0
     *   -progress-bar-height-factor: (0.20) 20% of the icon size
     *   -progress-bar-line-width: 1
     *   -progress-bar-top-offset: undefined
     *   -progress-bar-valign: 1.0
     *   -progress-bar-horizontal-padding: 0.05 (5% of icon size)
     *   -progress-bar-vertical-padding: 0.05 (5% of icon size)
     */
  -progress-bar-track-background: rgba(0, 0, 0, 0.45);
  -progress-bar-track-border: rgba(0, 0, 0, 0.7);
  -progress-bar-background: white;
  -progress-bar-border: white; }

#overview .progress-bar,
.apps-scroll-view .progress-bar {
  -progress-bar-height-factor: 0.15;
  -progress-bar-top-offset: 0;
  -progress-bar-valign: 0.95; }

#overview .grid-search-results .overview-tile .progress-bar,
#overview .app-folder-dialog .progress-bar {
  -progress-bar-height-factor: 0.13; }

#dashtodockContainer.top #dash .placeholder,
#dashtodockContainer.bottom #dash .placeholder {
  width: 32px;
  height: 1px; }

/*
 * This is applied to a dummy actor. Only the alpha value for the background and border color
 * and the transition-duration are used
 */
#dashtodockContainer.dummy-opaque {
  background-color: rgba(0, 0, 0, 0.8);
  border-color: rgba(0, 0, 0, 0.4);
  transition-duration: 300ms; }

/*
 * This is applied to a dummy actor. Only the alpha value for the background and border color
 * and the transition-duration are used
 */
#dashtodockContainer.dummy-transparent {
  background-color: rgba(0, 0, 0, 0.2);
  border-color: rgba(0, 0, 0, 0.1);
  transition-duration: 500ms; }

#dashtodockContainer .number-overlay,
.overview-tile .number-overlay,
.icon-grid .number-overlay {
  color: white;
  background-color: rgba(0, 0, 0, 0.8);
  text-align: center; }

#dashtodockContainer .notification-badge,
.overview-tile .notification-badge,
.icon-grid .notification-badge {
  color: white;
  background-color: red;
  padding: 0.2em 0.5em;
  border-radius: 1em;
  font-weight: bold;
  text-align: center;
  margin: 2px; }

#dashtodockPreviewSeparator.popup-separator-menu-item-horizontal {
  width: 1px;
  height: auto;
  border-right-width: 1px;
  margin: 32px 0px; }

#dashtodockContainer .metro .overview-icon {
  border-radius: 0px; }

#dashtodockContainer.bottom .metro.running2.focused,
#dashtodockContainer.top .metro.running2.focused {
  background-image: url("./media/highlight_stacked_bg.svg");
  background-position: 0px 0px;
  background-size: contain; }

#dashtodockContainer.left .metro.running2.focused,
#dashtodockContainer.right .metro.running2.focused {
  background-image: url("./media/highlight_stacked_bg_h.svg");
  background-position: 0px 0px;
  background-size: contain; }

#dashtodockContainer.bottom .metro.running3.focused,
#dashtodockContainer.top .metro.running3.focused {
  background-image: url("./media/highlight_stacked_bg.svg");
  background-position: 0px 0px;
  background-size: contain; }

#dashtodockContainer.left .metro.running3.focused,
#dashtodockContainer.right .metro.running3.focused {
  background-image: url("./media/highlight_stacked_bg_h.svg");
  background-position: 0px 0px;
  background-size: contain; }

#dashtodockContainer.bottom .metro.running4.focused,
#dashtodockContainer.top .metro.running4.focused {
  background-image: url("./media/highlight_stacked_bg.svg");
  background-position: 0px 0px;
  background-size: contain; }

#dashtodockContainer.left .metro.running4.focused,
#dashtodockContainer.right .metro.running4.focused {
  background-image: url("./media/highlight_stacked_bg_h.svg");
  background-position: 0px 0px;
  background-size: contain; }
